# Changelog

All notable changes to this project will be documented in this file.

## [0.13.0] - 2023-10-24

### Bug Fixes

- Keep track if a file needs to be closed

### Documentation

- Link codecov badge to main branch
- Add example jq_length

### Features

- Add support for Python 3.12

### Build

- Use rye instead of poetry

## [0.12.4] - 2023-03-10

### Bug Fixes

- Handle float in the same way

### Build

- Use ruff as linter
- Set minimum supported version to 3.9

## [0.12.3] - 2022-10-10

### Bug Fixes

- Handle gzip files for json_iter
- Handle gzip files for jsonl_iter
- Handle gzip files in sink

## [0.12.0] - 2022-05-26

### Bug Fixes

- Add utility is_gzip

### Features

- Add support for jsonl gzip
- Add support for json gzip
- Only use python 3.9+

### Refactor

- Add factory function for opening files

### Build

- Remove python 3.6 support

## [0.11.0] - 2021-11-16

### Bug Fixes

- Specify encoding to open

### Features

- Add decimal_encoder
- Allow keyword arguments to dump_to_file

### Testing

- Add streaming test
- Add encoding

## [0.10.1] - 2021-06-17

### Bug Fixes

- Remove ujson

## [0.10.0] - 2021-06-17

### Features

- Use pathlike from types


<!-- generated by git-cliff -->
